import wagtail_factories

from . import models


class PageWithColorFieldPageFactory(wagtail_factories.PageFactory):
    class Meta:
        model = models.PageWithColorField


class PageWithCharColorFieldPageFactory(wagtail_factories.PageFactory):
    class Meta:
        model = models.PageWithCharColorField


class PageWithDefaultValuePageFactory(wagtail_factories.PageFactory):
    class Meta:
        model = models.PageWithDefaultValue



from django.db import models
from wagtail.admin.panels import FieldPanel
from wagtail.fields import StreamField
from wagtail.models import Page

from wagtail_color_panel.blocks import NativeColorBlock
from wagtail_color_panel.edit_handlers import NativeColorPanel
from wagtail_color_panel.fields import ColorField


class PageWithColorField(Page):
    color = ColorField()

    content_panels = Page.content_panels + [
        NativeColorPanel("color"),
    ]


class PageWithCharColorField(Page):
    color = models.CharField(max_length=7)

    content_panels = Page.content_panels + [
        FieldPanel("color"),
    ]


class PageWithDefaultValue(Page):
    color = ColorField(default="#FF0000")

    content_panels = Page.content_panels + [
        NativeColorPanel("color"),
    ]


class PageWithStreamfield(Page):
    body = StreamField(
        [
            ("color", NativeColorBlock()),
        ],
        use_json_field=True,
    )

    content_panels = Page.content_panels + [
        FieldPanel("body"),
    ]



# Generated by Django 3.2.13 on 2022-06-23 02:07
from django.db import migrations

import wagtail.fields as wagtail_fields
import wagtail_color_panel.blocks


class Migration(migrations.Migration):
    dependencies = [
        ("testapp", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pagewithstreamfield",
            name="body",
            field=wagtail_fields.StreamField(
                [("color", wagtail_color_panel.blocks.NativeColorBlock())],
                use_json_field=True,
            ),
        ),
    ]



from wagtail.admin.panels import FieldPanel

from wagtail_color_panel.widgets import ColorInputWidget, PolyfillColorInputWidget


class NativeColorPanel(FieldPanel):
    def get_form_options(self):
        opts = super().get_form_options()
        opts["widgets"] = {
            self.field_name: ColorInputWidget(),
        }
        return opts


class PolyfillColorPanel(FieldPanel):
    def get_form_options(self):
        opts = super().get_form_options()
        opts["widgets"] = {
            self.field_name: PolyfillColorInputWidget(),
        }
        return opts



import json

from django.forms import widgets
from django.utils.safestring import mark_safe
from wagtail.telepath import register
from wagtail.utils.widgets import WidgetWithScript
from wagtail.widget_adapters import WidgetAdapter


class PolyfillColorInputWidget(widgets.TextInput):
    class Media:
        css = {
            "all": (
                "https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.0/spectrum.min.css",
            )
        }

        js = ("https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.0/spectrum.min.js",)

    def render(self, name, value, attrs=None, renderer=None):
        out = super().render(name, value, attrs, renderer=renderer)
        field_id = attrs["id"]

        return mark_safe(
            out
            + """
            <script>
            (function(){
                function init() {
                    $("#__FIELD_ID__").spectrum({
                        showPalette: false,
                        preferredFormat: "hex",
                        showInput: true,
                    });
                }

                if (document.readyState === 'complete') {
                    init({});
                }

                $(window).on('load', function() {
                    init();
                });
            })();
            </script>
            """.replace(
                "__FIELD_ID__", field_id
            )
        )


class ColorInputWidget(WidgetWithScript, widgets.TextInput):
    template_name = "wagtail_color_panel/widgets/color-input-widget.html"

    def __init__(self, attrs=None):
        default_attrs = {
            "class": "color-input-widget__text-input",
        }
        attrs = attrs or {}
        attrs = {**default_attrs, **attrs}
        super().__init__(attrs=attrs)

    def render_js_init(self, id_, name, value):
        return "new ColorInputWidget({0});".format(json.dumps(id_))

    class Media:
        css = {
            "all": [
                "wagtail_color_panel/css/color-input-widget.css",
            ]
        }
        js = [
            "wagtail_color_panel/js/color-input-widget.js",
        ]


class ColorInputWidgetAdapter(WidgetAdapter):
    js_constructor = "wagtail_color_panel.widgets.ColorInput"

    class Media:
        js = [
            "wagtail_color_panel/js/color-input-widget-telepath.js",
        ]


register(ColorInputWidgetAdapter(), ColorInputWidget)



import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

ADMINS = (("test@example.com", "test"),)

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": "tests.db",
    },
}

SECRET_KEY = "RANDOM"

INSTALLED_APPS = [
    "wagtail.contrib.forms",
    # 'wagtail.contrib.redirects',
    "wagtail.embeds",
    "wagtail.sites",
    "wagtail.users",
    "wagtail.snippets",
    "wagtail.documents",
    "wagtail.images",
    "wagtail.search",
    "wagtail.admin",
    "wagtail",
    "modelcluster",
    "taggit",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.messages",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.staticfiles",
    "wagtail_color_panel",
    "tests.testapp",
]

MIDDLEWARE = (
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.locale.LocaleMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
)

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [
            os.path.join(BASE_DIR, "templates"),
        ],
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
            "loaders": [
                "django.template.loaders.filesystem.Loader",
                "django.template.loaders.app_directories.Loader",
            ],
        },
    },
]

DEBUG = True
TEMPLATE_DEBUG = DEBUG
ROOT_URLCONF = "tests.urls"

WAGTAIL_SITE_NAME = ("Test Site",)
SITE_ID = 1
STATIC_URL = "/static/"



# Generated by Django 3.0.7 on 2020-07-31 06:52
from django.db import migrations, models
import django.db.models.deletion
import wagtail_color_panel.blocks
import wagtail_color_panel.fields

import wagtail.fields as wagtail_fields


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("wagtailcore", "0052_pagelogentry"),
    ]

    operations = [
        migrations.CreateModel(
            name="PageWithCharColorField",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                ("color", models.CharField(max_length=7)),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="PageWithColorField",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                ("color", wagtail_color_panel.fields.ColorField(max_length=7)),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="PageWithDefaultValue",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                (
                    "color",
                    wagtail_color_panel.fields.ColorField(
                        default="#FF0000", max_length=7
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.CreateModel(
            name="PageWithStreamfield",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.Page",
                    ),
                ),
                (
                    "body",
                    wagtail_fields.StreamField(
                        [("color", wagtail_color_panel.blocks.NativeColorBlock())]
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
    ]



from django.urls import include, path
from wagtail import urls as wagtail_urls
from wagtail.admin import urls as wagtailadmin_urls

urlpatterns = [
    path("admin/", include(wagtailadmin_urls)),
    path("", include(wagtail_urls)),
]
